@@ -21,6 +21,7 @@ from notebook.services.contents.manager import ContentsManager
 from collections import namedtuple
 from tornado import gen
 from nbformat.v4 import new_notebook
+from .cortx_authenticator import CortxAuthenticator
 import json 
 
 import nbformat
@@ -35,7 +36,6 @@ CredentialConfig = namedtuple('CredentialConfig', [
     'access_key_id', 'secret_access_key'
 ])
 
-# cortx_constants = {'NB_TYPE' :'.ipynb', 'UNTITLED_FILE' :'Untitled', 'FOLDER_SEPERATOR' : '/', 'UNTITLED_NB' :'Untitled', 'UNTITLED_FOLDER' : 'Untitled Folder','CHECKPOINT_NAME' : '.checkpoints'}
 
 class ExpiringDict:
 
@@ -71,16 +71,16 @@ class ExpiringDict:
 #     default_value = datetime.datetime(1900, 1, 1)
 
 
-class CortxAuthenticator(Configurable):
-    access_key_id = Unicode(config=True)
-    secret_access_key = Unicode(config=True)
+# class CortxAuthenticator(Configurable):
+#     access_key_id = Unicode(config=True)
+#     secret_access_key = Unicode(config=True)
 
-    @gen.coroutine
-    def get_credentials(self):
-        return CredentialConfig(
-            access_key_id=self.access_key_id,
-            secret_access_key=self.secret_access_key,
-        )
+#     @gen.coroutine
+#     def get_credentials(self):
+#         return CredentialConfig(
+#             access_key_id=self.access_key_id,
+#             secret_access_key=self.secret_access_key,
+#         )
 
 
 
